"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthService = void 0;
const common_1 = require("@nestjs/common");
const jwt_1 = require("@nestjs/jwt");
const prisma_service_1 = require("../prisma/prisma.service");
const user_service_1 = require("../user/user.service");
const bcrypt = require("bcrypt");
const cache_manager_1 = require("@nestjs/cache-manager");
let AuthService = class AuthService {
    constructor(jwtService, prisma, userService, cacheManager) {
        this.jwtService = jwtService;
        this.prisma = prisma;
        this.userService = userService;
        this.cacheManager = cacheManager;
    }
    async createToken(user) {
        const token = this.jwtService.sign({
            name: user.name,
            email: user.email,
        }, {
            expiresIn: "2 hours",
            subject: String(user.id),
            issuer: 'login',
            audience: "users"
        });
        const permissions = await this.userService.getPermisions(user.id);
        const data = {
            token: token,
            user: {
                name: user.name,
                email: user.email,
                username: user.username
            },
            permissions: permissions
        };
        return data;
    }
    checkToken(token) {
        try {
            const data = this.jwtService.verify(token, {
                audience: "users",
                issuer: "login",
            });
            return data;
        }
        catch (e) {
            console.log(e);
            throw new common_1.UnauthorizedException("Token Invalido!");
        }
    }
    isValidToken(token) {
        try {
            const a = this.jwtService.verify(token, {
                audience: "users",
                issuer: "login",
            });
            console.log('aqui ', a);
            return true;
        }
        catch (e) {
            return false;
        }
    }
    async login(email, password) {
        const user = await this.prisma.user.findFirst({
            where: {
                email: email,
            }
        });
        if (!user) {
            throw new common_1.BadRequestException("E-mail e/ou Senha Incorretos!");
        }
        try {
            const isMatch = await bcrypt.compare(password, user.password);
            console.log(isMatch);
            if (!isMatch) {
                throw new common_1.BadRequestException("Senha Incorreta!");
            }
        }
        catch (error) {
            throw new common_1.BadRequestException("Senha Incorreta!!");
        }
        return this.createToken(user);
    }
    async forget(email) {
        const user = await this.prisma.user.findFirst({
            where: {
                email: email,
            }
        });
        if (!user) {
            throw new common_1.UnauthorizedException("E-mail nao existe!");
        }
        return true;
    }
    async reset(password, token) {
        const id = "extraido do token";
        const user = await this.prisma.user.update({
            where: {
                id,
            },
            data: {
                password
            }
        });
        return this.createToken(user);
    }
    async register(data) {
        const user = await this.userService.create(data);
        return this.createToken(user);
    }
};
AuthService = __decorate([
    (0, common_1.Injectable)(),
    __param(3, (0, common_1.Inject)(cache_manager_1.CACHE_MANAGER)),
    __metadata("design:paramtypes", [jwt_1.JwtService,
        prisma_service_1.PrismaService,
        user_service_1.UserService, Object])
], AuthService);
exports.AuthService = AuthService;
//# sourceMappingURL=auth.service.js.map