"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CutterService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const user_service_1 = require("../user/user.service");
let CutterService = class CutterService {
    constructor(prisma, userService) {
        this.prisma = prisma;
        this.userService = userService;
    }
    async create(dados, user_id) {
        try {
            var data = {
                status: 1,
                name: dados.name,
                historico: await this.userService.criar_historico(user_id, dados)
            };
            return await this.prisma.cutter.create({
                data
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async findAll() {
        return this.prisma.cutter.findMany({
            where: {
                status: 1,
            },
            orderBy: {
                name: 'asc'
            }
        });
    }
    async search(filter) {
        return this.prisma.cutter.findMany({
            where: {
                name: {
                    contains: filter,
                    mode: 'insensitive',
                },
                status: 1,
            },
        });
    }
    async findOne(id) {
        try {
            return await this.prisma.cutter.findUnique({
                where: {
                    id
                }
            });
        }
        catch (error) {
            throw new common_1.NotFoundException(`Nao encontramos cutter com este id  ${id}`);
        }
    }
    async update(id, data, user_id) {
        const cutter = await this.ifExist(id);
        const old_historico = JSON.stringify(cutter.historico);
        delete (cutter.historico);
        delete (cutter.id);
        data.historico = await this.userService.update_historico(user_id, cutter, data, old_historico, "UPDATE");
        return this.prisma.cutter.update({
            data,
            where: {
                id
            }
        });
    }
    async delete(id, user_id) {
        const cutter = await this.ifExist(id);
        const old_historico = JSON.stringify(cutter.historico);
        delete (cutter.historico);
        delete (cutter.id);
        const data = {
            status: 0,
            historico: await this.userService.update_historico(user_id, cutter, { status: 0 }, old_historico, 'DELETE')
        };
        return this.prisma.cutter.update({
            data,
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        const cutter = await await this.findOne(id);
        if (!cutter) {
            throw new common_1.NotFoundException(`Nao encontramos cutter com este id  ${id}`);
        }
        return cutter;
    }
    tratar_erros_banco(error) {
        if (error.code === 'P2002') {
            if (error.meta.target == "cutter_name_key")
                throw new common_1.BadRequestException("Ya existe un cutter con este nombre");
        }
        else {
            return error;
        }
    }
};
CutterService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService, user_service_1.UserService])
], CutterService);
exports.CutterService = CutterService;
//# sourceMappingURL=cutter.service.js.map