"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EmprestimoService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const luxon_1 = require("luxon");
const livro_service_1 = require("../livro/livro.service");
const user_service_1 = require("../user/user.service");
let EmprestimoService = class EmprestimoService {
    constructor(prisma, livro, userService) {
        this.prisma = prisma;
        this.livro = livro;
        this.userService = userService;
    }
    async create(data) {
        await this.verifLivro(data.livro_id);
        data.data_emprestimo = await this.formatDatas(data.data_emprestimo);
        if (data.data_prazo)
            data.data_prazo = await this.formatDatas(data.data_prazo);
        if (data.data_entrega)
            data.data_entrega = await this.formatDatas(data.data_entrega);
        data.historico = await this.userService.criar_historico(data.user_id, data);
        const emprestimo = await this.prisma.emprestimo.create({ data });
        if (emprestimo)
            await this.livro.updateStatus(data.livro_id, 2);
        return emprestimo;
    }
    async findAll(establishment_id) {
        return this.prisma.emprestimo.findMany({
            where: {
                establishment_id: establishment_id,
                NOT: {
                    status: 0
                },
            },
            include: {
                livro: true
            },
            orderBy: {
                id: "desc"
            }
        });
    }
    async search(establishment_id, filter) {
        const status = filter.status;
        const text = filter.text;
        const type = filter.type;
        if (type == "livro") {
            return this.prisma.emprestimo.findMany({
                where: {
                    establishment_id: establishment_id,
                    status: status,
                    livro: {
                        titulo: {
                            contains: text,
                            mode: 'insensitive',
                        }
                    }
                },
                include: {
                    livro: true,
                    aluno: true
                },
                orderBy: {
                    id: "desc"
                }
            });
        }
        if (type == "aluno") {
            return this.prisma.emprestimo.findMany({
                where: {
                    establishment_id: establishment_id,
                    status: status,
                    aluno: {
                        name: {
                            contains: text,
                            mode: 'insensitive',
                        }
                    }
                },
                include: {
                    livro: true,
                    aluno: true
                },
                orderBy: {
                    id: "desc"
                }
            });
        }
        if (text != "" || text != null) {
            return this.prisma.emprestimo.findMany({
                where: {
                    establishment_id: establishment_id,
                    status: status,
                    OR: [
                        {
                            aluno: {
                                name: {
                                    contains: text,
                                    mode: 'insensitive',
                                }
                            }
                        },
                        {
                            livro: {
                                titulo: {
                                    contains: text,
                                    mode: 'insensitive',
                                }
                            }
                        }
                    ]
                },
                include: {
                    livro: true,
                    aluno: true
                },
                orderBy: {
                    id: "desc"
                }
            });
        }
        return this.prisma.emprestimo.findMany({
            where: {
                establishment_id: establishment_id,
                status: status,
            },
            include: {
                livro: true,
                aluno: true
            },
            orderBy: {
                id: "desc"
            }
        });
    }
    async findOne(id) {
        try {
            return await this.prisma.emprestimo.findUnique({
                where: {
                    id
                }
            });
        }
        catch (error) {
            throw new common_1.NotFoundException(`Nao encontramos emprestimos com este id  ${id}`);
        }
    }
    async update(id, data, user_id) {
        const emprestimo = await this.ifExist(id);
        if (emprestimo.livro_id != data.livro_id)
            await this.trocarLivro(emprestimo.livro_id, data.status, data.livro_id);
        console.log(data);
        if (data.data_prazo) {
            data.data_prazo = await this.formatDatas(data.data_prazo);
        }
        if (data.data_entrega) {
            data.data_entrega = await this.formatDatas(data.data_entrega);
        }
        if (data.data_emprestimo) {
            data.data_emprestimo = await this.formatDatas(data.data_emprestimo);
        }
        if (data.status == 2)
            await this.livro.updateStatus(data.livro_id, 1);
        const historico_atual = JSON.stringify(emprestimo.historico);
        delete (emprestimo.historico);
        delete (emprestimo.id);
        data.historico = await this.userService.update_historico(user_id, emprestimo, data, historico_atual, "UPDATE");
        return await this.prisma.emprestimo.update({
            data,
            where: {
                id
            }
        });
    }
    async finalizar(data, id, user_id) {
        data.status = 2;
        const emprestimo = await this.ifExist(id);
        if (data.data_entrega) {
            data.data_entrega = await this.formatDatas(data.data_entrega);
        }
        await this.livro.updateStatus(emprestimo.livro_id, 1);
        const historico_atual = JSON.stringify(emprestimo.historico);
        delete (emprestimo.historico);
        delete (emprestimo.id);
        data.historico = await this.userService.update_historico(user_id, emprestimo, data, historico_atual, "FINALIZAR");
        return await this.prisma.emprestimo.update({
            data,
            where: {
                id
            }
        });
    }
    async delete(id, user_id) {
        await this.ifExist(id);
        const emprestimo = await this.findOne(id);
        if (emprestimo.status == 1) {
            const livro = await this.livro.findOne(emprestimo.livro_id);
            if (livro.status == 2) {
                await this.livro.updateStatus(emprestimo.livro_id, 1);
            }
        }
        const old_historico = JSON.stringify(emprestimo.historico);
        delete (emprestimo.historico);
        delete (emprestimo.id);
        const data = {
            status: 0,
            historico: await this.userService.update_historico(user_id, emprestimo, { status: 0 }, old_historico, 'DELETE')
        };
        return this.prisma.emprestimo.update({
            data,
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        const emprestimo = await this.findOne(id);
        if (!(emprestimo)) {
            throw new common_1.NotFoundException(`Nao encontramos emprestimo com este id  ${id}`);
        }
        return emprestimo;
    }
    async verifLivro(id) {
        const livro = await this.livro.findOne(id);
        if (livro.status != 1) {
            throw new common_1.NotFoundException(`Este livro não pode ser emprestado, pois não esta com status ativo. Verificar se já não existe emprestimo!`);
        }
    }
    async trocarLivro(livro_id, status_emprestimo, new_livro_id) {
        await this.verifLivro(new_livro_id);
        await this.livro.updateStatus(livro_id, 1);
        if (status_emprestimo != 2)
            await this.livro.updateStatus(livro_id, 2);
    }
    async formatDatas(date) {
        const dateTime = luxon_1.DateTime.fromISO(date);
        const dataFormatada = dateTime.toISO();
        return dataFormatada;
    }
    async getEmprestimosCompanyAno(company_id, ano) {
        return this.prisma.emprestimo.findMany({
            where: {
                status: 2,
                establishment: {
                    company_id: company_id
                },
                data_emprestimo: {
                    gte: new Date(`${ano}-01-01T00:00:00.000Z`),
                    lt: new Date(`${parseInt(ano) + 1}-01-01T00:00:00.000Z`),
                },
            },
            include: {
                establishment: {
                    select: {
                        company_id: true
                    }
                }
            },
            orderBy: {
                id: "desc"
            }
        });
    }
    async getEmprestimosPorAnoEContagem(company_id, ano) {
        const emprestimosPorAno = await this.prisma.emprestimo.findMany({
            where: {
                status: 2,
                establishment: {
                    company_id: company_id,
                },
                data_emprestimo: {
                    gte: new Date(`${ano}-01-01T00:00:00.000Z`),
                    lt: new Date(`${parseInt(ano) + 1}-01-01T00:00:00.000Z`),
                },
            },
            orderBy: {
                data_emprestimo: "asc"
            }
        });
        const emprestimosPorMes = {};
        const meses = ["Enero", "Febrero", "Marzo", "Abril", "Mayo", "Junio", "Julio", "Agosto", "Septiembre", "Octubre", "Noviembre", "Diciembre"];
        const lista_meses = [];
        emprestimosPorAno.forEach((emprestimo) => {
            const data = new Date(emprestimo.data_emprestimo);
            const mes = data.getMonth() + 1;
            if (!emprestimosPorMes[mes]) {
                emprestimosPorMes[mes] = 0;
                lista_meses.push(meses[data.getMonth()]);
            }
            emprestimosPorMes[mes]++;
        });
        const num = Object.values(emprestimosPorMes);
        console.log(num);
        console.log(lista_meses);
        const dados = {
            meses: lista_meses,
            numeros: num
        };
        return dados;
    }
};
EmprestimoService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService, livro_service_1.LivroService, user_service_1.UserService])
], EmprestimoService);
exports.EmprestimoService = EmprestimoService;
//# sourceMappingURL=emprestimo.service.js.map