"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LivroService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const luxon_1 = require("luxon");
let LivroService = class LivroService {
    constructor(prisma) {
        this.prisma = prisma;
    }
    async create(data, estab_id) {
        data.establishment_id = estab_id;
        if (data.data_aquisicao)
            data.data_aquisicao = await this.formatDatas(data.data_aquisicao);
        return this.prisma.livro.create({
            data
        });
    }
    async findAllEstabelecimento(establishment_id) {
        return this.prisma.livro.findMany({
            where: {
                establishment_id,
                NOT: {
                    status: 0
                },
            },
            include: {
                categoria: {
                    select: {
                        nome: true,
                        id: true
                    },
                },
                Livro_scdd: {
                    where: {
                        status: 1
                    },
                    include: {
                        scdd: {
                            select: {
                                name: true,
                                id: true,
                                descricao: true
                            }
                        }
                    }
                },
                Livro_autor: {
                    where: {
                        status: 1
                    },
                    include: {
                        Autor: {
                            select: {
                                nome: true,
                                id: true
                            }
                        },
                        Cutter: {
                            select: {
                                name: true,
                                id: true
                            }
                        }
                    }
                }
            },
            orderBy: {
                id: "desc"
            }
        });
    }
    async findAll(text) {
        const data = this.prisma.livro.findMany({
            where: {
                OR: [
                    {
                        titulo: {
                            contains: text,
                            mode: 'insensitive'
                        },
                    },
                    {
                        editorial: {
                            contains: text,
                            mode: 'insensitive'
                        },
                    },
                    {
                        categoria: {
                            nome: {
                                contains: text,
                                mode: 'insensitive'
                            }
                        },
                    },
                ],
                AND: {
                    NOT: {
                        status: 0
                    }
                }
            },
            include: {
                categoria: {
                    select: {
                        nome: true,
                        id: true
                    },
                },
                Livro_autor: {
                    include: {
                        Autor: {
                            select: {
                                nome: true
                            }
                        },
                        Cutter: {
                            select: {
                                name: true
                            }
                        }
                    }
                },
                establishment: {
                    include: {
                        company: {
                            select: {
                                sigla: true
                            }
                        }
                    }
                }
            },
        });
        return (await data).map((element) => {
            return {
                company: element.establishment.company.sigla,
                establisment: element.establishment.name,
                titulo: element.titulo,
                editorial: element.editorial,
                edicao: element.edicao,
                ano: element.ano,
                status: element.status,
                autores: element.Livro_autor.map((e) => {
                    return e.Autor.nome + " ";
                }).flat()
            };
        });
    }
    async search(filter, establishment_id) {
        console.log(establishment_id);
        const categoria = filter.categoria_id;
        const titulo = filter.titulo;
        if (('categoria_id' in filter) && ('titulo' in filter)) {
            return this.prisma.livro.findMany({
                where: {
                    categoria_id: filter.categoria_id,
                    establishment_id,
                    titulo: {
                        contains: filter.titulo,
                        mode: 'insensitive',
                    },
                    NOT: {
                        status: 0
                    },
                },
                include: {
                    categoria: {
                        select: {
                            nome: true,
                            id: true
                        },
                    }
                },
            });
        }
        if ('titulo' in filter) {
            console.log("Só titulo");
            return this.prisma.livro.findMany({
                where: {
                    establishment_id,
                    OR: [
                        {
                            titulo: {
                                contains: titulo,
                                mode: 'insensitive'
                            },
                        },
                        { codigo: { contains: titulo } },
                    ],
                    NOT: {
                        status: 0
                    },
                },
                include: {
                    categoria: {
                        select: {
                            nome: true,
                            id: true
                        },
                    },
                },
            });
        }
        if ('categoria_id' in filter) {
            return this.prisma.livro.findMany({
                where: {
                    categoria_id: categoria,
                    establishment_id,
                    NOT: {
                        status: 0
                    },
                },
                include: {
                    categoria: {
                        select: {
                            nome: true,
                            id: true
                        },
                    },
                },
            });
        }
    }
    async findStatus(establishment_id, status) {
        return this.prisma.livro.findMany({
            where: {
                establishment_id,
                status: status
            },
            include: {
                categoria: {
                    select: {
                        nome: true,
                        id: true
                    },
                },
            },
        });
    }
    async findOne(id) {
        try {
            return await this.prisma.livro.findUnique({
                where: {
                    id
                }
            });
        }
        catch (error) {
            throw new common_1.NotFoundException(`Nao existe Livro com este id  ${id}`);
        }
    }
    async update(id, data) {
        await this.ifExist(id);
        if (data.data_aquisicao)
            data.data_aquisicao = await this.formatDatas(data.data_aquisicao);
        return await this.prisma.livro.update({
            data,
            where: {
                id
            }
        });
    }
    async updateStatus(id, status) {
        await this.ifExist(id);
        return await this.prisma.livro.update({
            data: {
                status: status
            },
            where: {
                id
            }
        });
    }
    async delete(id) {
        await this.ifExist(id);
        return this.prisma.livro.update({
            data: {
                status: 0
            },
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        if (!(await this.findOne(id))) {
            throw new common_1.NotFoundException(`Nao existe livro com este id  ${id}`);
        }
    }
    async formatDatas(date) {
        const dateTime = await luxon_1.DateTime.fromISO(date);
        return luxon_1.DateTime.utc().toISO(dateTime);
    }
};
LivroService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService])
], LivroService);
exports.LivroService = LivroService;
//# sourceMappingURL=livro.service.js.map