"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LivroScddService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const user_service_1 = require("../user/user.service");
let LivroScddService = class LivroScddService {
    constructor(prisma, userService) {
        this.prisma = prisma;
        this.userService = userService;
    }
    async create(dados, user_id) {
        try {
            var data = {
                status: 1,
                livro_id: dados.livro_id,
                scdd_id: dados.scdd_id,
                historico: await this.userService.criar_historico(user_id, dados)
            };
            return await this.prisma.livro_scdd.create({
                data
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async createMany(dados, user_id, livro_id) {
        console.log("dados!!", dados);
        dados.forEach(async (element) => {
            const historico = await this.userService.criar_historico(user_id, {
                livro_id: livro_id,
                scdd_id: element,
                status: 1
            });
            const data = { livro_id: livro_id, scdd_id: element, status: 1, historico: historico };
            await this.prisma.livro_scdd.create({
                data
            });
        });
    }
    async findOne(id) {
        try {
            return await this.prisma.livro_scdd.findUnique({
                where: {
                    id
                }
            });
        }
        catch (error) {
            throw new common_1.NotFoundException(`Nao encontramos livro_scdd com este id  ${id}`);
        }
    }
    async getLivroId(livro_id) {
        try {
            return await this.prisma.livro_scdd.findMany({
                where: {
                    livro_id,
                    status: 1
                }
            });
        }
        catch (error) {
            throw new common_1.NotFoundException(`Nao encontramos livro_scdd com este id  ${livro_id}`);
        }
    }
    async update(id, data, user_id) {
        const livro_scdd = await this.ifExist(id);
        const old_historico = JSON.stringify(livro_scdd.historico);
        delete (livro_scdd.historico);
        delete (livro_scdd.id);
        data.historico = await this.userService.update_historico(user_id, livro_scdd, data, old_historico, "UPDATE");
        try {
            return await this.prisma.livro_scdd.update({
                data,
                where: {
                    id
                }
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async delete(id, user_id) {
        const livro_scdd = await this.ifExist(id);
        const old_historico = JSON.stringify(livro_scdd.historico);
        delete (livro_scdd.historico);
        delete (livro_scdd.id);
        const data = {
            status: 0,
            historico: await this.userService.update_historico(user_id, livro_scdd, { status: 0 }, old_historico, 'DELETE')
        };
        return this.prisma.livro_scdd.update({
            data,
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        const livro_scdd = await await this.findOne(id);
        if (!livro_scdd) {
            throw new common_1.NotFoundException(`Nao encontramos livro_scdd com este id  ${id}`);
        }
        return livro_scdd;
    }
    tratar_erros_banco(error) {
        if (error.code === 'P2002') {
            if (error.meta.target == "livro_scdd_name_key")
                throw new common_1.BadRequestException("Ya existe un livro_scdd con este nombre");
        }
        else {
            return error;
        }
    }
};
LivroScddService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService, user_service_1.UserService])
], LivroScddService);
exports.LivroScddService = LivroScddService;
//# sourceMappingURL=livro_scdd.service.js.map