"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PermissionService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const prisma_exception_1 = require("../prisma/prisma.exception");
let PermissionService = class PermissionService {
    constructor(prisma) {
        this.prisma = prisma;
    }
    async create(data) {
        return this.prisma.permission.create({
            data
        });
    }
    async findAll() {
        const permission = await this.prisma.permission.findMany({
            where: {
                status: 1
            },
            orderBy: {
                name: "asc"
            }
        });
        const p = permission.map((e) => {
            return {
                name: e.name,
                createdAt: e.createdAt,
                updatedAt: e.updatedAt,
                status: e.status,
                id: e.id,
            };
        });
        return p;
    }
    async findOne(id) {
        try {
            return await this.prisma.permission.findUnique({
                where: {
                    id
                }
            });
        }
        catch (error) {
            throw new prisma_exception_1.PrismaException('Erro ao buscar id no banco. O formato de Id pode estar invalido!');
        }
    }
    async search(filter) {
        return this.prisma.permission.findMany({
            where: {
                name: {
                    contains: filter,
                    mode: 'insensitive',
                },
                status: 1,
            },
        });
    }
    async update(id, data) {
        await this.ifExist(id);
        return this.prisma.permission.update({
            data,
            where: {
                id
            }
        });
    }
    async remove(id) {
        await this.ifExist(id);
        return this.prisma.permission.update({
            data: {
                status: 0
            },
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        if (!(await this.findOne(id))) {
            throw new common_1.NotFoundException(`Não encontramos permissões com este id  ${id}`);
        }
    }
};
PermissionService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService])
], PermissionService);
exports.PermissionService = PermissionService;
//# sourceMappingURL=permission.service.js.map