"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const permission_has_role_service_1 = require("../permission_has_role/permission_has_role.service");
let RoleService = class RoleService {
    constructor(prisma, permisson_has_role) {
        this.prisma = prisma;
        this.permisson_has_role = permisson_has_role;
    }
    async create(data) {
        return this.prisma.role.create({
            data
        });
    }
    async findAll(establishment_id) {
        const roles = await this.prisma.role.findMany({
            where: {
                status: 1,
                establishment_id
            },
            include: {
                User_has_role: {
                    include: {
                        user: true
                    }
                },
                Permission_has_role: {
                    include: {
                        permission: true
                    }
                }
            },
            orderBy: {
                name: "asc"
            }
        });
        return roles.map((e) => {
            return {
                id: e.id,
                name: e.name,
                establishment_id: e.establishment_id,
                status: e.status,
                createdAt: e.createdAt,
                updatedAt: e.updatedAt,
                users: e.User_has_role.map((i) => { return { name: i.user.name, id: i.user.id }; }),
                permissions: e.Permission_has_role.map((p) => { return p.permission.id; })
            };
        });
    }
    async findOne(id) {
        return this.prisma.role.findUnique({
            where: {
                id
            }
        });
    }
    async update(id, data) {
        await this.ifExist(id);
        if (data.permissions) {
            data.role_id = id;
            await this.permisson_has_role.deleteAll(id);
            if (data.permissions.length > 0)
                await this.permisson_has_role.createMany(data);
            delete (data.permissions);
            delete (data.role_id);
        }
        return this.prisma.role.update({
            where: {
                id
            },
            data: {
                name: data.name,
            },
        });
    }
    async remove(id) {
        await this.ifExist(id);
        return this.prisma.role.update({
            data: {
                status: 0
            },
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        if (!(await this.findOne(id))) {
            throw new common_1.NotFoundException(`Não encontramos role com este id  ${id}`);
        }
    }
};
RoleService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService, permission_has_role_service_1.PermissionHasRoleService])
], RoleService);
exports.RoleService = RoleService;
//# sourceMappingURL=role.service.js.map