"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
const luxon_1 = require("luxon");
const bcrypt = require("bcrypt");
const common_2 = require("@nestjs/common");
let UserService = class UserService {
    constructor(prisma) {
        this.prisma = prisma;
    }
    async create(data) {
        if (!data.status)
            data.status = 1;
        const saltRounds = 10;
        const hashedPassword = await bcrypt.hash(data.password, saltRounds);
        data.password = hashedPassword;
        try {
            return await this.prisma.user.create({
                data
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async users() {
        return this.prisma.user.findMany({
            where: {
                status: 1
            }
        });
    }
    async userId(id) {
        return this.prisma.user.findUnique({
            where: {
                id
            }
        });
    }
    async update(id, data) {
        await this.ifExist(id);
        return this.prisma.user.update({
            data,
            where: {
                id
            }
        });
    }
    async delete(id) {
        await this.ifExist(id);
        return this.prisma.user.update({
            data: {
                status: 0
            },
            where: {
                id
            }
        });
    }
    async getRoles(id) {
        const userPermissions = await this.prisma.user.findUnique({
            where: { id: id },
            include: {
                User_has_role: {
                    include: {
                        role: {
                            include: {
                                Permission_has_role: {
                                    include: {
                                        permission: {
                                            select: {
                                                name: true
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        });
        const permissions = userPermissions.User_has_role.map((userRole) => userRole.role.Permission_has_role.map((permissionRole) => permissionRole.permission.name)).flat();
        return permissions;
    }
    async getPermisions(id) {
        const userPermissions = await this.prisma.user.findUnique({
            where: { id: id },
            include: {
                User_has_role: {
                    include: {
                        role: {
                            include: {
                                Permission_has_role: {
                                    include: {
                                        permission: {
                                            select: {
                                                name: true
                                            }
                                        }
                                    }
                                },
                                establishment: {
                                    select: {
                                        name: true,
                                        company_id: true
                                    },
                                },
                            }
                        }
                    }
                }
            }
        });
        const permissions = userPermissions.User_has_role.map(function (elemento) {
            return {
                establishment_id: elemento.role.establishment_id,
                establishment: elemento.role.establishment.name,
                company_id: elemento.role.establishment.company_id,
                role: elemento.role.name,
                permissions: elemento.role.Permission_has_role.map((permisionRole) => permisionRole.permission.name).flat()
            };
        }).flat();
        return permissions;
    }
    async ifExist(id) {
        if (!(await this.userId(id))) {
            throw new common_1.NotFoundException(`Nao encontramos user com este id  ${id}`);
        }
    }
    tratar_erros_banco(error) {
        if (error.code === 'P2002') {
            if (error.meta.target == "users_email_key")
                throw new common_2.BadRequestException("Já existe um usuario com este EMAIL");
            if (error.meta.target == "users_username_key")
                throw new common_2.BadRequestException("Já existe um usuario com este USERNAME");
        }
        else {
            return error;
        }
    }
    async criar_historico(user_id, data) {
        const user = await this.userId(user_id);
        const array = [];
        const date = luxon_1.DateTime.local({ zone: "America/Asuncion" });
        const historico = {
            type: "CREATE",
            user_id: user_id,
            name_user: user.name,
            old_value: null,
            new_value: data,
            date: date.toFormat('dd/MM/yyyy HH:mm:ss')
        };
        array.push(historico);
        return JSON.stringify(array);
    }
    async update_historico(user_id, old_value, new_value, historico, type) {
        const date = luxon_1.DateTime.local({ zone: "America/Asuncion" });
        const user = await this.userId(user_id);
        const array_historico = JSON.parse(JSON.parse(historico));
        console.log(array_historico);
        const new_historico = {
            type: type,
            user_id: user_id,
            name_user: user.name,
            old_value: old_value,
            new_value: new_value,
            date: date.toFormat('dd/MM/yyyy HH:mm:ss')
        };
        array_historico.push(new_historico);
        console.log(array_historico);
        return JSON.stringify(array_historico);
    }
};
UserService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService])
], UserService);
exports.UserService = UserService;
//# sourceMappingURL=user.service.js.map