"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsuarioService = void 0;
const common_1 = require("@nestjs/common");
const prisma_service_1 = require("../prisma/prisma.service");
let UsuarioService = class UsuarioService {
    constructor(prisma) {
        this.prisma = prisma;
    }
    async create(data) {
        if (data.cpf)
            await this.ifExistCPF(data.cpf);
        if (data.usuarios_id)
            await this.ifExistUsuarioID(data.usuarios_id);
        if (!data.status)
            data.status = 1;
        try {
            return await this.prisma.usuario.create({
                data
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async findAll() {
        return this.prisma.usuario.findMany({
            where: {
                status: 1
            },
            include: {
                User: {
                    select: {
                        username: true,
                        id: true
                    }
                }
            }
        });
    }
    async findPerfil(perfil_id) {
        return this.prisma.usuario.findMany({
            where: {
                status: 1,
                perfil_id: perfil_id
            },
            include: {
                User: {
                    select: {
                        username: true,
                        id: true
                    }
                }
            },
            orderBy: {
                id: "asc"
            },
            take: 50
        });
    }
    async search(perfil_id, dados) {
        if (dados.type == "rg") {
            return this.prisma.usuario.findMany({
                where: {
                    status: 1,
                    perfil_id: perfil_id,
                    rg_ci: {
                        contains: dados.text,
                        mode: 'insensitive'
                    }
                },
                include: {
                    User: {
                        select: {
                            username: true,
                            id: true
                        }
                    }
                }
            });
        }
        else {
            return this.prisma.usuario.findMany({
                where: {
                    status: 1,
                    perfil_id: perfil_id,
                    name: {
                        contains: dados.text,
                        mode: 'insensitive'
                    }
                },
                include: {
                    User: {
                        select: {
                            username: true,
                            id: true
                        }
                    }
                }
            });
        }
    }
    async usuarioId(id) {
        return this.prisma.usuario.findUnique({
            where: {
                id
            }
        });
    }
    async update(id, data) {
        await this.ifExist(id);
        return this.prisma.usuario.update({
            data,
            where: {
                id
            }
        });
    }
    async delete(id) {
        await this.ifExist(id);
        return this.prisma.usuario.update({
            data: {
                status: 0
            },
            where: {
                id
            }
        });
    }
    async ifExist(id) {
        if (!(await this.usuarioId(id))) {
            throw new common_1.NotFoundException(`Nao encontramos USUARIO com este id  ${id}`);
        }
    }
    tratar_erros_banco(error) {
        if (error.code === 'P2002') {
            if (error.meta.target == "users_email_key")
                throw new common_1.BadRequestException("Já existe um usuario com este EMAIL");
        }
        else {
            console.log("erro", error);
            return error;
        }
    }
    async ifExistCPF(cpf) {
        const user = await this.prisma.usuario.findFirst({
            where: {
                cpf: cpf
            }
        });
        if (user) {
            throw new common_1.NotFoundException(`Já existe um usuario com este CPF ${cpf}`);
        }
    }
    async createImport(data) {
        const verif = await this.ifExistUsuarioID(data.usuarios_id);
        if (verif) {
            if (data.cpf == null)
                delete (data.cpf);
            if (data.email == null)
                delete (data.email);
            if (data.rg_ci == null)
                delete (data.rg_ci);
            if (data.telefone == null)
                delete (data.telefone);
            try {
                return await this.prisma.usuario.create({
                    data
                });
            }
            catch (error) {
                return await this.tratar_erros_banco(error);
            }
        }
        else {
            console.log(`${data.name} não importado. usuarios_id: ${data.usuarios_id}, catraca: ${data.catraca}`);
        }
    }
    async createImportMany(data) {
        data.forEach(element => {
            if (element.cpf == null)
                delete (element.cpf);
            if (element.email == null)
                delete (element.email);
            if (element.rg_ci == null)
                delete (element.rg_ci);
            if (element.telefone == null)
                delete (element.telefone);
        });
        try {
            return await this.prisma.usuario.createMany({
                data
            });
        }
        catch (error) {
            return await this.tratar_erros_banco(error);
        }
    }
    async ifExistUsuarioID(usuarios_id) {
        const user = await this.prisma.usuario.findFirst({
            where: {
                usuarios_id
            }
        });
        if (user) {
            console.log(`Já existe um usuario com este numero de usario(usuarios_id) ${usuarios_id}`);
            return false;
        }
        return true;
    }
};
UsuarioService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [prisma_service_1.PrismaService])
], UsuarioService);
exports.UsuarioService = UsuarioService;
//# sourceMappingURL=usuario.service.js.map