import { Module, forwardRef } from '@nestjs/common';
import { CacheModule } from '@nestjs/cache-manager';
import { AppController } from './app.controller';
import { AppService } from './app.service';
import { UserModule } from './user/user.module';
import { PrismaModule } from './prisma/prisma.module';
import { CompanyModule } from './company/company.module';
import { EstablishmentModule } from './establishment/establishment.module';
import { PermissionModule } from './permission/permission.module';
import { RoleModule } from './role/role.module';
import { PermissionHasRoleModule } from './permission_has_role/permission_has_role.module';
import { UserHasRoleModule } from './user_has_role/user_has_role.module';
import { AuthModule } from './auth/auth.module';
import { CategoriaModule } from './categoria/categoria.module';
import { AutorModule } from './autor/autor.module';

//blblioteca de fora para email
import { MailerModule } from '@nestjs-modules/mailer';
import { PugAdapter } from '@nestjs-modules/mailer/dist/adapters/pug.adapter';
import { LivroModule } from './livro/livro.module';
import { EmprestimoModule } from './emprestimo/emprestimo.module';
import { JwtModule } from '@nestjs/jwt';
// import { ClassTransformer } from 'class-transformer';
import { PerfilModule } from './perfil/perfil.module';
import { UsuarioModule } from './usuario/usuario.module';
import { ScddModule } from './scdd/scdd.module';
import { CutterModule } from './cutter/cutter.module';
import { LivroAutorCutterModule } from './livro_autor_cutter/livro_autor_cutter.module';
import { FornecedorModule } from './fornecedor/fornecedor.module';
import { LivroScddModule } from './livro_scdd/livro_scdd.module';


@Module({
  imports: [
    forwardRef(() => UserModule), //forwardRef resolve problemas de circular dependency
    forwardRef(() => AuthModule),
    CacheModule.register(), 
    PrismaModule,
    CompanyModule,
    EstablishmentModule,
    PermissionModule,
    RoleModule,
    PermissionHasRoleModule,
    UserHasRoleModule,
    CategoriaModule,
    AutorModule,
    MailerModule.forRoot({
      transport: 'smtps://user@domain.com:pass@smtp.domain.com',
      defaults: {
        from: '"nest-modules" <modules@nestjs.com>',
      },
      template: {
        dir: __dirname + '/templates',
        adapter: new PugAdapter(),
        options: {
          strict: true,
        },
      },
    }),
    LivroModule,
    EmprestimoModule,
    PerfilModule,
    UsuarioModule,
    ScddModule,
    CutterModule,
    LivroAutorCutterModule,
    FornecedorModule,
    LivroScddModule,



  ],
  controllers: [AppController],
  providers: [AppService],
})
export class AppModule { }
