import { BadRequestException, Inject, Injectable, UnauthorizedException } from "@nestjs/common";
import { JwtService } from "@nestjs/jwt";
import { Prisma, User } from "@prisma/client";
import { throws } from "assert";
import { PrismaService } from "src/prisma/prisma.service";
import { AuthRegisterDTO } from "./dto/auth-register.dto";
import { UserService } from "src/user/user.service";
import { BADSTR } from "dns";
import * as bcrypt from 'bcrypt';
import { Cache } from "cache-manager";
import { CACHE_MANAGER } from "@nestjs/cache-manager";

@Injectable()
export class AuthService {

    constructor(
        private readonly jwtService: JwtService,
        private readonly prisma: PrismaService,
        private readonly userService: UserService,
        @Inject(CACHE_MANAGER) private cacheManager: Cache
    ) { }

    async createToken(user: User) {
        const token = this.jwtService.sign({
            name: user.name,
            email: user.email,
        }, {
            expiresIn: "2 hours",
            subject: String(user.id),
            issuer: 'login',
            audience: "users"
        });
        const permissions = await this.userService.getPermisions(user.id)
        const data = {
            token: token,
            user:{
                name:user.name,
                email:user.email,
                username:user.username
            },
            permissions:permissions
        }

        //salva permissoes teste
        // this.cacheManager.set('permissions',permissions,3600)

        return data



    }

    checkToken(token: string) {
        try {

            const data = this.jwtService.verify(token,
                {
                    audience: "users",
                    issuer: "login",
                }
            )
            return data
        } catch (e) {
            console.log(e)
            throw new UnauthorizedException("Token Invalido!")
        }
    }

    isValidToken(token: string) {
        try {
            const a = this.jwtService.verify(token,
                {
                    audience: "users",
                    issuer: "login",
                })
            console.log('aqui ', a)
            return true;
        } catch (e) {
            return false
        }
    }

    async login(email: string, password: string) {
        const user = await this.prisma.user.findFirst({
            where: {
                email: email,
            }
        })
        if (!user) {
            throw new BadRequestException("E-mail e/ou Senha Incorretos!")
        }

        try {
            const isMatch = await bcrypt.compare(password, user.password);
            console.log(isMatch)
            if (!isMatch) {

                throw new BadRequestException("Senha Incorreta!")
            }
        } catch (error) {
            throw new BadRequestException("Senha Incorreta!!")
        }



        return this.createToken(user)
    }
    async forget(email: string) {
        const user = await this.prisma.user.findFirst({
            where: {
                email: email,

            }
        })
        if (!user) {
            throw new UnauthorizedException("E-mail nao existe!")
        }

        //pesquisar como enviar email de confirmacao depois

        return true
    }
    async reset(password: string, token: string) {
        //TO DO: validar o token ...
        const id = "extraido do token";
        const user = await this.prisma.user.update({
            where: {
                id,
            },
            data: {
                password
            }
        });

        return this.createToken(user)


    }

    async register(data: AuthRegisterDTO) {
        const user = await this.userService.create(data);
        return this.createToken(user)
    }
}