import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards, Put } from '@nestjs/common';
import { AutorService } from './autor.service';
import { CreateAutorDto } from './dto/create-autor.dto';
import { UpdateAutorDto } from './dto/update-autor.dto';
import { AuthGuard } from 'src/guards/auth.guard';
import { Company } from 'src/decorators/company_decorator';

// @UseGuards(AuthGuard) ver problemas de dependencia circular depois

@UseGuards(AuthGuard)
@Controller('autor')
export class AutorController {
  constructor(private readonly autorService: AutorService) { }

  @Post()
  async create(@Body() createAutorDto: CreateAutorDto, @Company() company_id) {
    createAutorDto.company_id = company_id
    return this.autorService.create(createAutorDto);
  }

  @Get()
  async findAll(@Company() company_id) {
    return this.autorService.findAll(company_id);
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.autorService.findOne(id);
  }

  @Get('search/:filter')
  async getRoles(@Param('filter') filter: string, @Company() company_id) {
    return this.autorService.search(filter,company_id)
  }

  @Put(':id')
  async update(@Param('id') id: string, @Body() updateAutorDto: UpdateAutorDto) {
    return this.autorService.update(id, updateAutorDto);
  }

  @Delete(':id')
  async remove(@Param('id') id: string) {
    return this.autorService.delete(id);
  }
}
