import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateAutorDto } from './dto/create-autor.dto';
import { UpdateAutorDto } from './dto/update-autor.dto';
import { PrismaService } from 'src/prisma/prisma.service';

@Injectable()
export class AutorService {
  constructor(private prisma: PrismaService) { }

  async create(data: CreateAutorDto) {

    return this.prisma.autor.create({
      data
    });

  }

  async findAll(company_id: string) {
    return this.prisma.autor.findMany({
      where: {
        status: 1,
        company_id
      }
    });
  }

  async search(filter: string, company_id:string) {
    return this.prisma.autor.findMany({

      where: {
        nome: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
        company_id
      },
    });
  }

  async findOne(id: string) {
    try {
      return await this.prisma.autor.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao existe autor com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateAutorDto) {
    await this.ifExist(id)

    return await this.prisma.autor.update({
      data,
      where: {
        id
      }
    })
  }

  async delete(id: string) {

    await this.ifExist(id)

    return this.prisma.autor.update({
      data: {
        status: 0
      },
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Nao existe autor com este id  ${id}`);
    }
  }
}
