import { Controller, Get, Post, Body, Patch, Param, Delete, Put, UseGuards } from '@nestjs/common';
import { CategoriaService } from './categoria.service';
import { CreateCategoriaDto } from './dto/create-categoria.dto';
import { UpdateCategoriaDto } from './dto/update-categoria.dto';
import { AuthGuard } from 'src/guards/auth.guard';
import { Company } from 'src/decorators/company_decorator';
import { combineAll } from 'rxjs';

@UseGuards(AuthGuard)
@Controller('categoria')
export class CategoriaController {
  constructor(private readonly categoriaService: CategoriaService) { }

  @Post()
  create(@Body() data: CreateCategoriaDto, @Company() company_id) {
    data.company_id = company_id
    return this.categoriaService.create(data);
  }

  @Get()
  findAll(@Company() company_id) {
    return this.categoriaService.findAll(company_id);
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.categoriaService.findOne(id);
  }

  @Get('search/:filter')
  async getRoles(@Param('filter') filter: string, @Company() company_id) {
    return this.categoriaService.search(filter, company_id)
  }

  @Put(':id')
  update(@Param('id') id: string, @Body() updateCategoriaDto: UpdateCategoriaDto) {
    console.log(updateCategoriaDto)
    delete (updateCategoriaDto['id'])
    console.log(updateCategoriaDto)
    return this.categoriaService.update(id, updateCategoriaDto);
  }

  @Delete(':id')
  remove(@Param('id') id: string) {
    return this.categoriaService.delete(id);
  }
}
