import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateCategoriaDto } from './dto/create-categoria.dto';
import { UpdateCategoriaDto } from './dto/update-categoria.dto';
import { PrismaService } from 'src/prisma/prisma.service';

@Injectable()
export class CategoriaService {

  constructor(private prisma: PrismaService) { }

  async create(data: CreateCategoriaDto) {
    return this.prisma.categoria.create({ data })
  }

  async findAll(company_id:string) {
    return this.prisma.categoria.findMany({
      where: {
        status: 1,
        company_id
      },
      orderBy:{
        nome:'asc'
      }
     
    });
  }

  async search(filter: string, company_id: string) {
    return this.prisma.categoria.findMany({

      where: {
        nome: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
        company_id
      },
    });
  }

  async findOne(id: string) {
    try {
      return await this.prisma.categoria.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos categoria com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateCategoriaDto) {
    await this.ifExist(id)

    return this.prisma.categoria.update({
      data,
      where: {
        id
      }
    })
  }

  async delete(id: string) {

    await this.ifExist(id)

    return this.prisma.categoria.update({
      data: {
        status: 0
      },
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Nao encontramos categoria com este id  ${id}`);
    }
  }
}
