import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards } from '@nestjs/common';
import { CompanyService } from './company.service';
import { CreateCompanyDto } from './dto/create-company.dto';
import { UpdateCompanyDto } from './dto/update-company.dto';
import { AuthGuard } from 'src/guards/auth.guard';

@Controller('company')
export class CompanyController {
  constructor(private readonly companyService: CompanyService) { }

  @Post()
  //COLOCAR EXCECAO SIGLA VALOR UNICO DEPOIS
  @UseGuards(AuthGuard)
  async create(@Body() createCompanyDto: CreateCompanyDto) {
   return this.companyService.create(createCompanyDto)
  }

  @Get()
  findAll() {
    return this.companyService.findAll();
  }
  
  @UseGuards(AuthGuard)
  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.companyService.findOne(id)
  }

  @UseGuards(AuthGuard)
  @Patch(':id')
  async update(@Param('id') id: string, @Body() data: UpdateCompanyDto) {
    return this.companyService.update(id, data)
  }

  @UseGuards(AuthGuard)
  @Delete(':id')
  async delete(@Param('id') id: string) {
    return this.companyService.delete(id);
  }



}
