import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateCompanyDto } from './dto/create-company.dto';
import { UpdateCompanyDto } from './dto/update-company.dto';
import { PrismaService } from 'src/prisma/prisma.service';

@Injectable()
export class CompanyService {

  constructor(private prisma: PrismaService) { }

  async create(data: CreateCompanyDto) {

    return this.prisma.company.create({
      data
    });

  }

  async findAll() {
    return this.prisma.company.findMany({
      where: {
        status: 1
      }
    });
  }

  findOne(id: string) {
    return this.prisma.company.findUnique({
      where: {
        id
      }
    })
  }

  async update(id: string, data: UpdateCompanyDto) {
    await this.ifExist(id)

    return this.prisma.company.update({
      data,
      where: {
        id
      }
    })
  }

  async delete(id: string) {

    await this.ifExist(id)

    return this.prisma.company.update({
      data:{
        status:0
      },
      where:{
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Nao encontramos empresa com este id  ${id}`);
    }
  }
  
}
