import { Controller, Get, Post, Body, Patch, Param, Delete, Put, UseGuards } from '@nestjs/common';
import { CutterService } from './cutter.service';
import { CreateCutterDto } from './dto/create-cutter.dto';
import { UpdateCutterDto } from './dto/update-cutter.dto';
import { User } from 'src/decorators/user.decorator';
import { AuthGuard } from 'src/guards/auth.guard';
@UseGuards(AuthGuard)
@Controller('cutter')

export class CutterController {
  constructor(private readonly cutterService: CutterService) { }

  @Post()
  create(@Body() data: CreateCutterDto, @User() user_id) {
    return this.cutterService.create(data, user_id);
  }

  @Get()
  findAll() {
    return this.cutterService.findAll();
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.cutterService.findOne(id);
  }

  @Get('search/:filter')
  async getRoles(@Param('filter') filter: string) {
    return this.cutterService.search(filter)
  }

  @Put(':id')
  update(@Param('id') id: string, @Body() data: UpdateCutterDto, @User() user_id) {
    console.log(data)
    delete (data['id'])
    console.log(data) 
    return this.cutterService.update(id, data, user_id);
  }

  @Delete(':id')
  remove(@Param('id') id: string, @User() user_id) {
    return this.cutterService.delete(id, user_id);
  }


}
