import { BadRequestException, Injectable, NotFoundException, UseGuards } from '@nestjs/common';
import { PrismaService } from 'src/prisma/prisma.service';
import { CreateCutterDto } from './dto/create-cutter.dto';
import { UpdateCutterDto } from './dto/update-cutter.dto';
import { UserService } from 'src/user/user.service';
import { AuthGuard } from 'src/guards/auth.guard';

@Injectable()

export class CutterService {

  constructor(private prisma: PrismaService, private userService: UserService) { }

  async create(dados: CreateCutterDto, user_id: string) {
    try {
      var data = {
        status: 1,
        name: dados.name,
        historico: await this.userService.criar_historico(user_id, dados)
      }
      return await this.prisma.cutter.create({
        data
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async findAll() {
    return this.prisma.cutter.findMany({
      where: {
        status: 1,
      },
      orderBy: {
        name: 'asc'
      }

    });
  }

  async search(filter: string) {
    return this.prisma.cutter.findMany({

      where: {
        name: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
      },
    });
  }

  async findOne(id: string) {
    try {
      return await this.prisma.cutter.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos cutter com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateCutterDto, user_id: string) {
    const cutter = await this.ifExist(id)
    const old_historico = JSON.stringify(cutter.historico)
    delete (cutter.historico)
    delete (cutter.id)
    data.historico = await this.userService.update_historico(user_id, cutter, data, old_historico, "UPDATE")
    return this.prisma.cutter.update({
      data,
      where: {
        id
      }
    })
  }

  async delete(id: string, user_id: string) {

    const cutter = await this.ifExist(id)
    const old_historico = JSON.stringify(cutter.historico)
    delete (cutter.historico)
    delete (cutter.id)

    const data = {
      status: 0,
      historico: await this.userService.update_historico(user_id, cutter, { status: 0 }, old_historico, 'DELETE')
    }
    return this.prisma.cutter.update({
      data,
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    const cutter = await await this.findOne(id)
    if (!cutter) {
      throw new NotFoundException(`Nao encontramos cutter com este id  ${id}`);
    }
    return cutter
  }

  tratar_erros_banco(error) {
    if (error.code === 'P2002') {
      if (error.meta.target == "cutter_name_key") throw new BadRequestException("Ya existe un cutter con este nombre")
    } else {
      return error
    }
  }

}
