import { Type } from "class-transformer";
import { IsDate, IsDateString, IsNotEmpty, IsNumber, IsOptional, IsString, Validate, isISO8601, isObject } from "class-validator";
import { CustomTextValidator } from "src/custom-validators/custom-validators";

export class CreateEmprestimoDto {
    @IsString({ message: 'A descrição deve ser uma string' })
    descricao: string

    @IsNumber()
    status: number

    @IsNotEmpty({ message: 'O campo livro_id não pode estar vazio' })
    @IsString({ message: 'O campo livro_id deve ser uma string' })
    livro_id: string

    @IsNotEmpty({ message: 'O campo aluno_id não pode estar vazio' })
    @IsString({ message: "aluno_id deve ser un object_id" })
    aluno_id: string

    @Validate(CustomTextValidator)
    nome_aluno: string

    @IsOptional()
    @IsString({ message: 'O campo user_id deve ser uma string' })
    user_id: string

    @IsOptional()
    @IsString({ message: 'O campo establishment_id deve ser uma string' })
    establishment_id: string

    @IsDateString()
    @Type(() => isISO8601)
    data_emprestimo: Date

    @IsOptional()
    @IsDateString()
    @Type(() => isISO8601)
    data_prazo: Date

    @IsOptional()
    @IsDateString()
    @Type(() => isISO8601)
    data_entrega: Date

    @IsOptional()
    historico: string
}
