import { PartialType } from '@nestjs/mapped-types';
import { CreateEmprestimoDto } from './create-emprestimo.dto';
import { IsDateString, IsNotEmpty, IsNumber, IsOptional, IsString, Validate, isISO8601 } from 'class-validator';
import { CustomTextValidator } from 'src/custom-validators/custom-validators';
import { Type } from 'class-transformer';

export class UpdateEmprestimoDto extends PartialType(CreateEmprestimoDto) {
    @IsString({message:'A descrição deve ser uma string'})
    descricao: string

    @IsNumber()
    status: number

    @IsNotEmpty({message:'O campo livro_id não pode estar vazio'})
    @IsString({message:'O campo livro_id deve ser uma string'})
    livro_id:string

    @IsOptional()
    @IsNotEmpty({message:'O campo aluno_id não pode estar vazio'})
    @IsString({message:"aluno_id deve ser un numero"})
    aluno_id:string

    @IsOptional()
    @Validate(CustomTextValidator)
    nome_aluno:string
 
    @IsOptional()
    @IsOptional()
    @IsString({message:'O campo user_id deve ser uma string'})
    user_id:string

    @IsOptional()
    @IsNotEmpty({message:'O campo establishment_id não pode estar vazio'})
    @IsString({message:'O campo establishment_id deve ser uma string'})
    establishment_id:string

    @IsOptional()
    @IsDateString()
    @Type(() => isISO8601)
    data_emprestimo:Date

    @IsOptional()
    @IsDateString()
    @Type(() => isISO8601)
    data_prazo:Date

    @IsOptional()
    @IsDateString()
    @Type(() => isISO8601)
    data_entrega:Date

    @IsOptional()
    historico: string
}

