import { Controller, Get, Post, Body, Put, Param, Delete, UseGuards, BadRequestException } from '@nestjs/common';
import { EmprestimoService } from './emprestimo.service';
import { CreateEmprestimoDto } from './dto/create-emprestimo.dto';
import { UpdateEmprestimoDto } from './dto/update-emprestimo.dto';
import { AuthGuard } from 'src/guards/auth.guard';
import { User } from 'src/decorators/user.decorator';
import { Establishment } from 'src/decorators/establishment.decorator';
import { FinalizarEmprestimoDto } from './dto/finalizar-emprestimo';
import { FilterEmprestimoDto } from './dto/filter-emprestimo';
import { Company } from 'src/decorators/company_decorator';
import { GraficoEmprestimoDto } from './dto/grafico-emprestimo';


@UseGuards(AuthGuard)
@Controller('emprestimo')
export class EmprestimoController {
  constructor(private readonly emprestimoService: EmprestimoService) { }


  @Post()
  create(@Body() createEmprestimoDto: CreateEmprestimoDto, @User() user, @Establishment() estab_id) {
    if (user) {
      createEmprestimoDto.user_id = user
      createEmprestimoDto.establishment_id = estab_id
      console.log(createEmprestimoDto)
      return this.emprestimoService.create(createEmprestimoDto)
    } else {
      throw new BadRequestException("Não foi possivel identificar o user_id no token. Realizar login novamente.")
    }
  }

  @Get()
  findAll(@Establishment() estab_id) {
    return this.emprestimoService.findAll(estab_id);
  }

  @Post('search')
  search(@Establishment() estab_id, @Body() filter: FilterEmprestimoDto) {
    return this.emprestimoService.search(estab_id, filter);
  }

  @Put('finalizar:id')
  finalizar(@Param('id') id: string, @Body() data: FinalizarEmprestimoDto, @User() user_id) {
    return this.emprestimoService.finalizar(data, id, user_id);
  }

  @Get(':id')
  findOne(@Param('id') id: string) {
    return this.emprestimoService.findOne(id);
  }

  @Put(':id')
  update(@Param('id') id: string, @Body() updateEmprestimoDto: UpdateEmprestimoDto, @User() user_id) {
    return this.emprestimoService.update(id, updateEmprestimoDto, user_id);
  }

  @Delete(':id')
  remove(@Param('id') id: string, @User() user_id) {
    return this.emprestimoService.delete(id, user_id);
  }


  @Post('graficos')
  getEmprestimosCompanyAno(@Company() company_id, @Body() data: GraficoEmprestimoDto) {
    console.log(company_id)
    return this.emprestimoService.getEmprestimosPorAnoEContagem(company_id, data.ano);
  }

}
