import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards } from '@nestjs/common';
import { EstablishmentService } from './establishment.service';
import { CreateEstablishmentDto } from './dto/create-establishment.dto';
import { UpdateEstablishmentDto } from './dto/update-establishment.dto';
import { AuthGuard } from 'src/guards/auth.guard';

@Controller('establishment')
export class EstablishmentController {
  constructor(private readonly establishmentService: EstablishmentService) { }

  @UseGuards(AuthGuard)
  @Post()
  async create(@Body() data: CreateEstablishmentDto) {
    return this.establishmentService.create(data);
  }

  @Get()
  async findAll() {
    return this.establishmentService.findAll();
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.establishmentService.findOne(id);
  }

  @Patch(':id')
  async update(@Param('id') id: string, @Body() data: UpdateEstablishmentDto) {
    return this.establishmentService.update(id, data);
  }

  @Delete(':id')
  async delete(@Param('id') id: string) {
    return this.establishmentService.delete(id);
  }
}
