import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateEstablishmentDto } from './dto/create-establishment.dto';
import { UpdateEstablishmentDto } from './dto/update-establishment.dto';
import { PrismaService } from 'src/prisma/prisma.service';

@Injectable()
export class EstablishmentService {


constructor(private prisma: PrismaService){}

  async create(data: CreateEstablishmentDto) {
 
    return this.prisma.establishment.create({
      data
    });

  }

  async findAll() {
    return this.prisma.establishment.findMany({
      where: {
        status: 1
      }
    });
  }

  findOne(id: string) {
    return this.prisma.establishment.findUnique({
      where: {
        id
      }
    })
  }

  async update(id: string, data: UpdateEstablishmentDto) {
    await this.ifExist(id)

    return this.prisma.establishment.update({
      data,
      where: {
        id
      }
    })
  }

  async delete(id: string) {

    await this.ifExist(id)

    return this.prisma.establishment.update({
      data:{
        status:0
      },
      where:{
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Nao encontramos estabelecimento com este id  ${id}`);
    }
  }
}
