import { Controller, Get, Post, Body, Patch, Param, Delete, Put, UseGuards } from '@nestjs/common';
import { User } from 'src/decorators/user.decorator';
import { AuthGuard } from 'src/guards/auth.guard';
import { FornecedorService } from './fornecedor.service';
import { CreateFornecedorDto } from './dto/create-fornecedor.dto';
import { UpdateFornecedorDto } from './dto/update-fornecedor.dto';
@UseGuards(AuthGuard)
@Controller('fornecedor')

export class FornecedorController {
  constructor(private readonly fornecedorService: FornecedorService) { }

  @Post()
  create(@Body() data: CreateFornecedorDto, @User() user_id) {
    return this.fornecedorService.create(data, user_id);
  }

  @Get()
  findAll() {
    return this.fornecedorService.findAll();
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.fornecedorService.findOne(id);
  }

  @Get('search/:filter')
  async getRoles(@Param('filter') filter: string) {
    return this.fornecedorService.search(filter)
  }

  @Put(':id')
  update(@Param('id') id: string, @Body() data: UpdateFornecedorDto, @User() user_id) {
    console.log(data)
    delete (data['id'])
    console.log(data) 
    return this.fornecedorService.update(id, data, user_id);
  }

  @Delete(':id')
  remove(@Param('id') id: string, @User() user_id) {
    return this.fornecedorService.delete(id, user_id);
  }


}
