import { BadRequestException, Injectable, NotFoundException } from '@nestjs/common';
import { PrismaService } from 'src/prisma/prisma.service';
import { UserService } from 'src/user/user.service';
import { CreateFornecedorDto } from './dto/create-fornecedor.dto';
import { UpdateFornecedorDto } from './dto/update-fornecedor.dto';

@Injectable()
export class FornecedorService {
  constructor(private prisma: PrismaService, private userService: UserService) { }

  async create(dados: CreateFornecedorDto, user_id: string) {
    try {
      var data = {
        status: 1,
        name: dados.name,
        sigla: dados.sigla,
        historico: await this.userService.criar_historico(user_id, dados)
      }
      return await this.prisma.fornecedor.create({
        data
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async findAll() {
    return this.prisma.fornecedor.findMany({
      where: {
        status: 1,
      },
      orderBy: {
        name: 'asc'
      }

    });
  }

  async search(filter: string) {
    return this.prisma.fornecedor.findMany({

      where: {
        name: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
      },
    });
  }

  async findOne(id: string) {
    try {
      return await this.prisma.fornecedor.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos fornecedor com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateFornecedorDto, user_id: string) {
    const fornecedor = await this.ifExist(id)
    const old_historico = JSON.stringify(fornecedor.historico)
    delete (fornecedor.historico)
    delete (fornecedor.id)
    data.historico = await this.userService.update_historico(user_id, fornecedor, data, old_historico, "UPDATE")
    try {
      return await this.prisma.fornecedor.update({
        data,
        where: {
          id
        }
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async delete(id: string, user_id: string) {

    const fornecedor = await this.ifExist(id)
    const old_historico = JSON.stringify(fornecedor.historico)
    delete (fornecedor.historico)
    delete (fornecedor.id)

    const data = {
      status: 0,
      historico: await this.userService.update_historico(user_id, fornecedor, { status: 0 }, old_historico, 'DELETE')
    }
    return this.prisma.fornecedor.update({
      data,
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    const fornecedor = await await this.findOne(id)
    if (!fornecedor) {
      throw new NotFoundException(`Nao encontramos fornecedor com este id  ${id}`);
    }
    return fornecedor
  }

  tratar_erros_banco(error) {
    if (error.code === 'P2002') {
      if (error.meta.target == "fornecedor_name_key") throw new BadRequestException("Ya existe un fornecedor con este nombre")
    } else {
      return error
    }
  }

}
