import { Transform, ClassTransformer } from "class-transformer";
import { IsArray, IsDateString, IsNotEmpty, IsNumber, IsOptional, IsString, Validate } from "class-validator";
import { CustomTextValidator } from "src/custom-validators/custom-validators";
import validator from "validator";

export class CreateLivroDto {

    @IsNotEmpty({ message: "El titulo no debe estar vazio" })
    @Validate(CustomTextValidator)
    @IsString({ message: "O campo titulo deve ser uma string e não pode ser vazio" })
    @Transform(({ value }) => value.trim())
    titulo: string;

    @Validate(CustomTextValidator)
    editorial: string

    @IsNumber({}, { message: "El campo status debe ser un numero" })
    status: number

    @IsNotEmpty({ message: "El año del libro no debe estar vazio" })
    @IsNumber({}, { message: "El campo año debe ser un numero" })
    ano: number

    @IsNotEmpty({ message: "El campo Fila no puede ser vazio" })
    @IsString({ message: "El campo Fila debe ser un texto" })
    fila: string

    @IsNotEmpty({ message: "El campo Coluna no puede ser vazio" })
    @IsString({ message: "El campo Colula debe ser un texto" })
    coluna: string

    @IsNotEmpty({ message: "El campo Seccion no puede ser vazio" })
    @IsString({ message: "El campo Seccion debe ser un texto" })
    secao: string

    @IsNotEmpty({ message: "El Codigo no puede ser vazio" })
    @IsString({ message: "El Codigo debe ser una string" })
    codigo: string

    @IsNotEmpty({ message: "Es necessário vincular por lo menos un código SCDD al crear el libro" })
    @IsArray({ message: "El Codigo SCDD debe ser una lista con uno o mas codigos" })
    lista_scdd: string[]

    @IsNotEmpty({ message: "Es necessário vincular por lo menos un AUTOR para crear el libro" })
    @IsArray({ message: "lista_autores debe ser una lista con uno o mas id de autores" })
    lista_autores: string[]

    @IsNotEmpty({ message: "El campo CUTTER debe estar selecionado" })
    @IsString({ message: "El campo cutter_id debe ser un texto" })
    cutter_id: string

    //OPTIONALS
    @IsOptional()
    @IsString({ message: "El campo Categoria_id debe ser un texto" })
    categoria_id: string

    @IsOptional() 
    @IsString()
    descricao: string

    @IsOptional()
    @IsString()
    establishment_id: string

    @IsOptional()
    @IsString({ message: "El campo fornecedor_id debe ser un texto" })
    fornecedor_id: string

    @IsOptional()
    @IsNumber({}, { message: "El campo edicion debe ser un numero" })
    edicao: number

    @IsOptional()
    @IsNumber({}, { message: "El campo volume debe ser un numero" })
    volume: string

    @IsOptional()
    @IsNumber({}, { message: "El campo exemplar debe ser un numero" })
    exemplar: number

    @IsOptional()
    @IsNumber({}, { message: "El campo total_paginas debe ser un numero" })
    total_paginas: number

    @IsOptional()
    @IsNumber({}, { message: "El campo costo debe ser un numero" })
    custo: number

    @IsOptional()
    @IsDateString({},{message:"data_aquisicao debe ser una string de datas"})
    data_aquisicao:Date

}
