import { Controller, Get, Post, Body, Put, Param, Delete, UseGuards } from '@nestjs/common';
import { CreateLivroDto } from './dto/create-livro.dto';
import { UpdateLivroDto } from './dto/update-livro.dto';
import { AuthGuard } from 'src/guards/auth.guard';
import { Establishment } from 'src/decorators/establishment.decorator';
import { LivroService } from './livro.service';
import { LivroScddService } from 'src/livro_scdd/livro_scdd.service';
import { User } from 'src/decorators/user.decorator';
import { LivroAutorCutterService } from 'src/livro_autor_cutter/livro_autor_cutter.service';
import { CreateManyLivroAutor } from 'src/livro_autor_cutter/dto/create-many-livor_autor';



@Controller('livro')
export class LivroController {
  constructor(private readonly livroService: LivroService, private readonly livroScddService: LivroScddService, private readonly livroAutorService: LivroAutorCutterService) { }

  @UseGuards(AuthGuard)
  @Post()
  async create(@Body() data: CreateLivroDto, @Establishment() estab_id, @User() user_id) {
    // return data
    const list_scdd = data.lista_scdd
    const list_autores = data.lista_autores
    const cutter_id = data.cutter_id
    delete(data.lista_scdd)
    delete(data.lista_autores)
    delete(data.cutter_id)
    const livro =  await this.livroService.create(data, estab_id);
    if(livro){
      await this.livroScddService.createMany(list_scdd, user_id,livro.id)
      const autores = await this.livroAutorService.createMany({livro_id:livro.id, autors: list_autores, cutter_id: cutter_id, status:1})
      console.log(autores)
    }

    return livro
  }

  @UseGuards(AuthGuard)
  @Get()
  async findAllEstabelecimento(@Establishment() estab) {
    return this.livroService.findAllEstabelecimento(estab);
  }

  @Get('searchAll/:text')
  async findAll(@Param('text') text: string) {
    return this.livroService.findAll(text)
  }

  @UseGuards(AuthGuard)
  @Post('search')
  async getRoles(@Body() data: UpdateLivroDto, @Establishment() estab) {
    return this.livroService.search(data, estab)
  } 

  @UseGuards(AuthGuard)
  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.livroService.findOne(id);
  }

  @UseGuards(AuthGuard)
  @Get('status/:num')
  async findStatus(@Param('num') num: number, @Establishment() estab) {
    console.log(num)
    return this.livroService.findStatus(estab, Number(num));
  }

  @UseGuards(AuthGuard)
  @Put(':id')
  async update(@Param('id') id: string, @Body() data: UpdateLivroDto) {
    console.log(data)
    return this.livroService.update(id, data);
  }

  @UseGuards(AuthGuard)
  @Delete(':id')
  async remove(@Param('id') id: string) {
    return this.livroService.delete(id);
  }
}
