import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateLivroAutorCutterDto } from './dto/create-livro_autor_cutter.dto';
import { UpdateLivroAutorCutterDto } from './dto/update-livro_autor_cutter.dto';
import { PrismaService } from 'src/prisma/prisma.service';
import { CreateManyLivroAutor } from './dto/create-many-livor_autor';

@Injectable()
export class LivroAutorCutterService {
  constructor(private prisma: PrismaService) { }
  create(data: CreateLivroAutorCutterDto) {
    data.status = 1
    return this.prisma.livro_autor_cutter.create({ data });
  }
  
  createMany(dados: CreateManyLivroAutor) {
    if (dados.autors.length > 0) {
      var data = []
      dados.autors.forEach(iten => {
        data.push({ livro_id: dados.livro_id, autor_id: iten, cutter_id: dados.cutter_id, status: 1 })
      })
      return this.prisma.livro_autor_cutter.createMany({ data })
    }
  }

  findAll(livro_id: string) {
    return this.prisma.livro_autor_cutter.findMany(
      {
        where:{
          status:1,
          livro_id:livro_id,
        },
        include:{
          Autor:true
        }
      }
    )
  }

  async findOne(id: string) {
    try {
      return await this.prisma.livro_autor_cutter.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao existe Livro com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateLivroAutorCutterDto) {
    await this.ifExist(id)

    return await this.prisma.livro_autor_cutter.update({
      data,
      where: {
        id
      }
    })
  }
  async updateStatus(id: string, status: number) {
    await this.ifExist(id)

    return await this.prisma.livro_autor_cutter.update({
      data: {
        status: status
      },
      where: {
        id
      }
    })
  }

  async delete(id: string) {

    await this.ifExist(id)

    return this.prisma.livro_autor_cutter.update({
      data: {
        status: 0
      },
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Nao existe livro com este id  ${id}`);
    }
  }
}
