import { BadRequestException, Injectable, NotFoundException, UseGuards } from '@nestjs/common';
import { PrismaService } from 'src/prisma/prisma.service';
import { UserService } from 'src/user/user.service';
import { CreateLivroScddDto } from './dto/create-livro_scdd.dto';
import { UpdateLivroScddDto } from './dto/update-livro_scdd.dto';
import { CreateScddDto } from 'src/scdd/dto/create-scdd.dto';

@Injectable()
export class LivroScddService {
  constructor(private prisma: PrismaService, private userService: UserService) { }

  async create(dados: CreateLivroScddDto, user_id: string) {
    try {
      var data = {
        status: 1,
        livro_id: dados.livro_id,
        scdd_id: dados.scdd_id,
        historico: await this.userService.criar_historico(user_id, dados)
      }
      return await this.prisma.livro_scdd.create({
        data
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }
  }

  async createMany(dados: string[], user_id: string, livro_id: string) {
    // var list = []
    console.log("dados!!", dados)
    dados.forEach(async element => {
      const historico = await this.userService.criar_historico(user_id, {
        livro_id: livro_id,
        scdd_id: element,
        status: 1
      })
      const data = { livro_id: livro_id, scdd_id: element, status: 1, historico: historico }
      await this.prisma.livro_scdd.create({
        data
      })
    });
  }

  // async findAll() {
  //   return this.prisma.livro_scdd.findMany({
  //     where: {
  //       status: 1,
  //     },
  //     orderBy: {
  //       name: 'asc'
  //     }

  //   });
  // }

  // async search(filter: string) {
  //   return this.prisma.livro_scdd.findMany({

  //     where: {
  //       name: {
  //         contains: filter,
  //         mode: 'insensitive',
  //       },
  //       status: 1,
  //     },
  //   });
  // }
  async findOne(id: string) {
    try {
      return await this.prisma.livro_scdd.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos livro_scdd com este id  ${id}`);
    }
  }
  async getLivroId(livro_id: string) {
    try {
      return await this.prisma.livro_scdd.findMany({
        where: {
          livro_id,
          status:1
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos livro_scdd com este id  ${livro_id}`);
    }
  }

  async update(id: string, data: UpdateLivroScddDto, user_id: string) {
    const livro_scdd = await this.ifExist(id)
    const old_historico = JSON.stringify(livro_scdd.historico)
    delete (livro_scdd.historico)
    delete (livro_scdd.id)
    data.historico = await this.userService.update_historico(user_id, livro_scdd, data, old_historico, "UPDATE")
    try {
      return await this.prisma.livro_scdd.update({
        data,
        where: {
          id
        }
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async delete(id: string, user_id: string) {

    const livro_scdd = await this.ifExist(id)
    const old_historico = JSON.stringify(livro_scdd.historico)
    delete (livro_scdd.historico)
    delete (livro_scdd.id)

    const data = {
      status: 0,
      historico: await this.userService.update_historico(user_id, livro_scdd, { status: 0 }, old_historico, 'DELETE')
    }
    return this.prisma.livro_scdd.update({
      data,
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    const livro_scdd = await await this.findOne(id)
    if (!livro_scdd) {
      throw new NotFoundException(`Nao encontramos livro_scdd com este id  ${id}`);
    }
    return livro_scdd
  }

  tratar_erros_banco(error) {
    if (error.code === 'P2002') {
      if (error.meta.target == "livro_scdd_name_key") throw new BadRequestException("Ya existe un livro_scdd con este nombre")
    } else {
      return error
    }
  }

}
