import { Injectable, NotFoundException } from '@nestjs/common';
import { CreatePermissionDto } from './dto/create-permission.dto';
import { UpdatePermissionDto } from './dto/update-permission.dto';
import { PrismaService } from 'src/prisma/prisma.service';
import { PrismaException } from 'src/prisma/prisma.exception';

@Injectable()
export class PermissionService {
  constructor(private prisma: PrismaService) { }

  async create(data: CreatePermissionDto) {

    return this.prisma.permission.create({
      data
    });

  }

  async findAll() {
    const permission = await this.prisma.permission.findMany({
      where: {
        status: 1
      },
      orderBy:{
        name:"asc"
      }
      // include: {
      //   Permission_has_role: {
      //     include: { role: true }, // Incluir as informações da role associada
      //   },
      // },
    });

    const p = permission.map((e)=>{
      return {
        name: e.name,
        createdAt:e.createdAt,
        updatedAt:e.updatedAt,
        status:e.status,
        id:e.id,
        // roles: e.Permission_has_role.map((rol)=>{return rol.role.name})
      }
    })

    return p

  }

  async findOne(id: string) {
    try {
      return await this.prisma.permission.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new PrismaException('Erro ao buscar id no banco. O formato de Id pode estar invalido!');
    }
  }

  async search(filter: string) {
    return this.prisma.permission.findMany({
      where: {
        name: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
      },
    });
  }

  async update(id: string, data: UpdatePermissionDto) {

    await this.ifExist(id)

    return this.prisma.permission.update({
      data,
      where: {
        id
      }
    })

  }

  async remove(id: string) {

    await this.ifExist(id)

    return this.prisma.permission.update({
      data: {
        status: 0
      },
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Não encontramos permissões com este id  ${id}`);
    }
  }

}
