import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards } from '@nestjs/common';
import { PermissionHasRoleService } from './permission_has_role.service';
import { CreatePermissionHasRoleDto } from './dto/create-permission_has_role.dto';
import { UpdatePermissionHasRoleDto } from './dto/update-permission_has_role.dto';
import { CreateAssingPermissionHasRoleDto } from './dto/create-assing.dto copy';
import { AuthGuard } from 'src/guards/auth.guard';
import { Establishment } from 'src/decorators/establishment.decorator';
import { RoleService } from 'src/role/role.service';

@UseGuards(AuthGuard)
@Controller('permission-has-role')
export class PermissionHasRoleController {
  constructor(private readonly permissionHasRoleService: PermissionHasRoleService, private readonly roleService: RoleService) { }

  @Post()
  create(@Body() createPermissionHasRoleDto: CreatePermissionHasRoleDto) {
    return this.permissionHasRoleService.create(createPermissionHasRoleDto);
  }

  @Post('create_assign')
  async create_assign(@Body() data: CreateAssingPermissionHasRoleDto, @Establishment() estab_id) {
    //cria a role e ja vincula array de permissions 
    const role = await this.roleService.create({
      name: data.name_role,
      status: data.status,
      establishment_id: estab_id
    })

    return this.permissionHasRoleService.create({
      permissions: data.permissions,
      role_id: role.id,
      permission_id:null,
    });

  }

  @Get()
  findAll() {
    return this.permissionHasRoleService.findAll();
  }

  @Get(':id')
  findRole(@Param('id') id: string) {
    return this.permissionHasRoleService.permissiosRole(id);
  }


  @Delete(':id')
  remove(@Param('id') id: string) {
    return this.permissionHasRoleService.remove(id);
  }
}
