import { Injectable } from '@nestjs/common';
import { CreatePermissionHasRoleDto } from './dto/create-permission_has_role.dto';
import { UpdatePermissionHasRoleDto } from './dto/update-permission_has_role.dto';
import { PrismaService } from 'src/prisma/prisma.service';

@Injectable()
export class PermissionHasRoleService {

  constructor(private prisma: PrismaService) { }

  async create(data: CreatePermissionHasRoleDto) {
    if (data.permissions) {
     return this.createMany(data)
    } else {
      return this.prisma.permission_has_role.create({ data })
    }

  }

  async createMany(data) {
    const roles = []
    data.permissions.forEach(element => {
      roles.push({ role_id: data.role_id, permission_id: element })
    });
    return this.prisma.permission_has_role.createMany({ data: roles })
  }

  async findAll() {
    return this.prisma.permission_has_role.findMany({
      include: {
        role: {
          select: {
            name: true
          }
        },
        permission: {
          select: {
            name: true
          }
        }
      },
    
    })
  }

  async permissiosRole(id: string) {
    return this.prisma.permission_has_role.findMany({
      where: {
        role_id: id
      },
      include: {
        role: {
          select: {
            name: true
          }
        },
        permission: {
          select: {
            name: true
          }
        }
      },
      orderBy:{
        permission:{
          name:"asc"
        }
      }
    })
  }

  async findOne(id: string) {
    return this.prisma.permission_has_role.findUnique({
      where: {
        id
      },


    })
  }

  deleteAll(role_id: string) {
    return this.prisma.permission_has_role.deleteMany({
      where: {
        role_id: role_id
      }
    })
  }


  remove(id: string) {
    return this.prisma.permission_has_role.delete({
      where: {
        id
      }
    })
  }
}
