import { Injectable, NotFoundException } from '@nestjs/common';
import { CreateRoleDto } from './dto/create-role.dto';
import { UpdateRoleDto } from './dto/update-role.dto';
import { PrismaService } from 'src/prisma/prisma.service';
import { PermissionHasRoleService } from 'src/permission_has_role/permission_has_role.service';

@Injectable()
export class RoleService {
  constructor(private prisma: PrismaService, private permisson_has_role: PermissionHasRoleService) { }

  async create(data: CreateRoleDto) {

    return this.prisma.role.create({
      data
    });

  }

  async findAll(establishment_id: string) {
    const roles = await this.prisma.role.findMany({
      where: {
        status: 1,
        establishment_id
      },
      include: {
        User_has_role: {
          include: {
            user: true
          }
        },
        Permission_has_role: {
          include: {
            permission: true
          }
        }
      },
      orderBy:{
        name:"asc"
      }
    });

    return roles.map((e) => {
      return {
        id: e.id,
        name: e.name,
        establishment_id: e.establishment_id,
        status: e.status,
        createdAt: e.createdAt,
        updatedAt: e.updatedAt,
        users: e.User_has_role.map((i) => { return { name: i.user.name, id: i.user.id } }),
        permissions: e.Permission_has_role.map((p) => { return p.permission.id })

      }
    })
  }

  async findOne(id: string) {

    return this.prisma.role.findUnique({
      where: {
        id
      }
    })
  }

  async update(id: string, data: UpdateRoleDto) {

    await this.ifExist(id)

    if (data.permissions) {
      data.role_id = id
      await this.permisson_has_role.deleteAll(id)
      if (data.permissions.length > 0)
        await this.permisson_has_role.createMany(data)

      delete (data.permissions)
      delete (data.role_id)
    }

    return this.prisma.role.update({
      where: {
        id
      },
      data: {
        name: data.name,
      },
    })

  }

  async remove(id: string) {

    await this.ifExist(id)

    return this.prisma.role.update({
      data: {
        status: 0
      },
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    if (!(await this.findOne(id))) {
      throw new NotFoundException(`Não encontramos role com este id  ${id}`);
    }
  }

}
