import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards, Put } from '@nestjs/common';
import { ScddService } from './scdd.service';
import { CreateScddDto } from './dto/create-scdd.dto';
import { UpdateScddDto } from './dto/update-scdd.dto';
import { User } from 'src/decorators/user.decorator';
import { AuthGuard } from 'src/guards/auth.guard';

@UseGuards(AuthGuard)
@Controller('scdd')
export class ScddController {
  constructor(private readonly scddService: ScddService) { }

  @Post()
  create(@Body() data: CreateScddDto, @User() user_id) {
    return this.scddService.create(data, user_id);
  }

  @Get()
  findAll() {
    return this.scddService.findAll();
  }

  @Get(':id')
  findOne(@Param('id') id: string) {
    return this.scddService.findOne(id);
  }

  @Get('search/:filter')
  async search(@Param('filter') filter: string) {
    return this.scddService.search(filter)
  }

  @Put(':id')
  update(@Param('id') id: string, @Body() data: UpdateScddDto, @User() user_id) {
    return this.scddService.update(id, data, user_id);
  }

  @Delete(':id')
  remove(@Param('id') id: string, @User() user_id) {
    return this.scddService.delete(id, user_id)
  }
}
