import { BadRequestException, Injectable, NotFoundException, UseGuards } from '@nestjs/common';
import { CreateScddDto } from './dto/create-scdd.dto';
import { UpdateScddDto } from './dto/update-scdd.dto';
import { PrismaService } from 'src/prisma/prisma.service';
import { UserService } from 'src/user/user.service';
import { AuthGuard } from 'src/guards/auth.guard';


@Injectable()
export class ScddService {
  constructor(private prisma: PrismaService, private userService: UserService) { }

  async create(dados: CreateScddDto, user_id: string) {
    try {
      var data = {
        status: 1,
        name: dados.name,
        historico: await this.userService.criar_historico(user_id, dados)
      }
      return await this.prisma.scdd.create({
        data
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async findAll() {
    return this.prisma.scdd.findMany({
      where: {
        status: 1,
      },
      orderBy: {
        name: 'asc'
      }

    });
  }

  async search(filter: string) {
    return this.prisma.scdd.findMany({

      where: {
        name: {
          contains: filter,
          mode: 'insensitive',
        },
        status: 1,
      },
    });
  }

  async findOne(id: string) {
    try {
      return await this.prisma.scdd.findUnique({
        where: {
          id
        }
      })
    } catch (error) {
      throw new NotFoundException(`Nao encontramos scdd com este id  ${id}`);
    }
  }

  async update(id: string, data: UpdateScddDto, user_id: string) {
    const scdd = await this.ifExist(id)
    const old_historico = JSON.stringify(scdd.historico)
    delete (scdd.historico)
    delete (scdd.id)
    data.historico = await this.userService.update_historico(user_id, scdd, data, old_historico, "UPDATE")
    try {
      return await this.prisma.scdd.update({
        data,
        where: {
          id
        }
      })
    } catch (error) {
      return await this.tratar_erros_banco(error)
    }

  }

  async delete(id: string, user_id: string) {

    const scdd = await this.ifExist(id)
    const old_historico = JSON.stringify(scdd.historico)
    delete (scdd.historico)
    delete (scdd.id)

    const data = {
      status: 0,
      historico: await this.userService.update_historico(user_id, scdd, { status: 0 }, old_historico, 'DELETE')
    }
    return this.prisma.scdd.update({
      data,
      where: {
        id
      }
    })
  }

  async ifExist(id: string) {
    const scdd = await await this.findOne(id)
    if (!scdd) {
      throw new NotFoundException(`Nao encontramos scdd com este id  ${id}`);
    }
    return scdd
  }

  tratar_erros_banco(error) {
    if (error.code === 'P2002') {
      if (error.meta.target == "scdd_name_key") throw new BadRequestException("Ya existe un scdd con este nombre")
    } else {
      return error
    }
  }

}
