
// import { Transform } from "class-transformer";
import { IsEmail, IsString, IsStrongPassword, IsNumber, IsNotEmpty, IsOptional, Validate } from "class-validator";
import { IsValidCPF } from "src/custom-validators/cpf-validator";
import { CustomTextValidator } from "src/custom-validators/custom-validators";

export class CreateUserDto {
    @Validate(CustomTextValidator)
    @IsString({ message: 'O campo name deve ser uma string' })
    @IsNotEmpty({ message: 'O campo name não pode ser vazio' })
    name: string;

    @Validate(CustomTextValidator)
    @IsString({ message: 'O campo username deve ser uma string' })
    @IsNotEmpty({ message: 'O campo username não pode ser vazio' })
    username: string;

    @IsEmail({}, { message: 'O campo de e-mail deve ser um endereço de e-mail válido' })
    email: string;

    @IsStrongPassword({
        minLength: 6,
        minLowercase: 0,
        minNumbers: 0,
        minSymbols: 0,
        minUppercase: 0,
    })
    password: string;

    @IsOptional()
    @IsNumber()
    status: number

    @IsOptional()
    company_id: string

    @IsNotEmpty({message:"Informe un usuario_id ja existente"})
    @IsString()
    usuario_id: string
}


