import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards } from '@nestjs/common';
import { UserService } from './user.service';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';
import { RolesGuard } from 'src/guards/roles.guard';
import { Roles } from 'src/decorators/roles.decorator';
import { Role } from 'src/enums/role.enum';
import { AuthGuard } from "src/guards/auth.guard";
import { Test } from '@nestjs/testing';
import { Admin } from 'mongodb';
import { Company } from 'src/decorators/company_decorator';

@UseGuards(AuthGuard,RolesGuard)
@Controller('user')
export class UserController {
  constructor(private readonly userService: UserService) { }

 
  @Post()
  async create(@Body() data: CreateUserDto, @Company() company_id) {
    // return data
    data.company_id = company_id
    return this.userService.create(data);
  }

  @Roles(Role.Admin)
  @Get()
  async findAll() {
    return this.userService.users()
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return this.userService.userId(id)
  }

  @Get('role/:id')
  async getRoles(@Param('id') id: string) {
    return this.userService.getRoles(id)
  }
  @Get('permisions/:id')
  async getPermisions(@Param('id') id: string) {
    return this.userService.getPermisions(id)
  }

  @Patch(':id')
  async update(@Param('id') id: string, @Body() data: UpdateUserDto) {
    return this.userService.update(id, data)
  }

  @Delete(':id')
  remove(@Param('id') id: string) {
    return this.userService.delete(id);
  }
}
