import { PartialType } from '@nestjs/mapped-types';
import { CreateUsuarioDto } from './create-usuario.dto';
import { IsEmail, IsNotEmpty, IsNumber, IsOptional, IsString, Validate } from 'class-validator';
import { CustomTextValidator } from 'src/custom-validators/custom-validators';
import { IsValidCPF } from 'src/custom-validators/cpf-validator';

export class UpdateUsuarioDto extends PartialType(CreateUsuarioDto) {
    @IsOptional()
    @Validate(CustomTextValidator)
    @IsString({ message: 'O campo name deve ser uma string' })
    @IsNotEmpty({ message: 'O campo name não pode ser vazio' })
    name: string;

    @IsOptional()
    @IsEmail({}, { message: 'O campo de e-mail deve ser um endereço de e-mail válido' })
    email: string;

    @IsOptional()
    @IsOptional()
    @IsNumber()
    status: number

    @IsOptional()
    @Validate(CustomTextValidator)
    rg_ci: string

    @IsOptional()
    @Validate(CustomTextValidator)
    telefone: string

    @IsOptional()
    @IsString({ message: "CPF deve ser uma string" })
    @IsValidCPF()
    cpf: string


    @IsNotEmpty({message:"Perfil debe estar selecionado"})
    perfil_id:string

    @IsOptional()
    establishment_id: string

    @IsOptional()
    company_id: string

    @IsOptional()
    username:string
}
