import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards, NotFoundException, BadRequestException, Put } from '@nestjs/common';
import { UsuarioService } from './usuario.service';
import { CreateUsuarioDto } from './dto/create-usuario.dto';
import { UpdateUsuarioDto } from './dto/update-usuario.dto';
import { Establishment } from 'src/decorators/establishment.decorator';
import { Company } from 'src/decorators/company_decorator';
import { UserService } from 'src/user/user.service';
import { AuthGuard } from 'src/guards/auth.guard';
import { FilterUsuarioDto } from './dto/filter-usuario.dto';
import { HttpService } from '@nestjs/axios';
import axios, { AxiosResponse, formToJSON } from 'axios';
import { Usuario } from '@prisma/client';
import { json } from 'node:stream/consumers';
import { ImportAlunosDto } from './dto/import-alunos.dto';
import { ObjectId } from 'mongodb';
import { elementAt } from 'rxjs';

type Aluno = {
  usuarios_id: number,
  doc_oficial: string,
  telefone: string,
  cpf: string,
  semestre: string,
  periodo: string,
  email: string,
  config_filial_id: number,
  numero_catraca: number,
  nome_usuario: string
}

@UseGuards(AuthGuard)
@Controller('usuario')
export class UsuarioController {
  constructor(private readonly usuarioService: UsuarioService, private readonly userService: UserService, private readonly httpService: HttpService) { }

  @Post()
  async create(@Body() data: CreateUsuarioDto, @Establishment() estab_id, @Company() company_id) {
    data.establishment_id = estab_id
    data.company_id = company_id
    const username = data.username
    delete (data.username)

    const usuario = await this.usuarioService.create(data);

    if (usuario && data.perfil_id == '64c7d1eb239bc21e224aad11') { //perfil funcionario

      if (username != "") {

        await this.userService.create({
          name: data.name,
          email: data.email,
          company_id: company_id,
          password: data.rg_ci,
          username: username,
          status: 1,
          usuario_id: usuario.id
        })

      } else {
        throw new BadRequestException("Si estas cadastrando un funcionario debes enviar e campo USERNAME")
      }


    }

    return username
  }

  @Get()
  findAll() {
    return this.usuarioService.findAll();
  }

  @Get('perfil/:perfil')
  findPerfil(@Param('perfil') perfil: string) {
    return this.usuarioService.findPerfil(perfil);
  }

  @Post('search/:perfil')
  search(@Param('perfil') perfil: string, @Body() dados: FilterUsuarioDto) {
    return this.usuarioService.search(perfil, dados);
  }

  // @Get(':id')
  // findOne(@Param('id') id: string) {
  //   return this.usuarioService.findOne(+id);
  // }

  @Put(':id')
  update(@Param('id') id: string, @Body() updateUsuarioDto: UpdateUsuarioDto) {
    return this.usuarioService.update(id, updateUsuarioDto);
  }

  @Delete(':id')
  remove(@Param('id') id: string) {
    return this.usuarioService.delete(id);
  }


  @Get('importAlunos')
  async importarAlunos() {
    const lista_alunos_json = await this.getAlunos()
    const lista_alunos: Aluno[] = lista_alunos_json.map((alunoJson: any) => ({
      usuarios_id: alunoJson.usuarios_id,
      doc_oficial: alunoJson.doc_oficial,
      telefone: alunoJson.telefone,
      cpf: alunoJson.cpf,
      semestre: alunoJson.semestre,
      periodo: alunoJson.periodo,
      email: alunoJson.email,
      config_filial_id: alunoJson.config_filial_id,
      numero_catraca: alunoJson.numero_catraca,
      nome_usuario: alunoJson.nome_usuario,
    }));

    let test = []
    const total = lista_alunos.length
    return total
    lista_alunos.forEach(async element => {
      var company_id = '647e60c86f226de98c5719b1'
      if (element.config_filial_id == 2) {
        company_id = '647e60246f226de98c5719af';
      } else {
        company_id = '647e60c86f226de98c5719b1';
      }
      const aluno = {
        name: element.nome_usuario,
        status: 1,
        catraca: element.numero_catraca,
        cpf: element.cpf,
        rg_ci: element.doc_oficial,
        company_id: company_id,
        email: element.email,
        semestre_atual: element.semestre,
        periodo: element.periodo,
        usuarios_id: element.usuarios_id,
        telefone: element.telefone,
        perfil_id: '64c7d1f5239bc21e224aad12'
      };

      test.push(aluno)

      if (test.length == 6619) {
        console.log(test)
        const create_alunos =  await this.usuarioService.createImportMany(test)
        test = []
      }
      // const create_alunos =  await this.usuarioService.createImport(aluno)

      // console.log(create_alunos);
    });

    return test

  }
  // teste 
  // importarAlunos(): Promise<AxiosResponse<Aluno[]>> {
  //   const data = this.httpService.axiosRef.get('https://api.ucpvirtual.com.br/api/getAlunosAtivos');
  //   console.log(data)
  //   return data
  //   //                   
  // }

  async getAlunos() {
    try {
      const response = await axios.get('https://api.ucpvirtual.com.br/api/getAlunosAtivos');
      if (response.status === 200) {
        const data = response.data;
        return data
      } else {
        throw new Error('Erro ao acessar a API externa');
      }
    } catch (error) {
      throw new Error('Erro ao importar alunos: ' + error.message);
    }
  }
}
